# Emerging Trajectories

Open source library for tracking and saving forecasts of political, economic, and social events.

## Installation

```bash
pip install emergingtrajectories
```

## Questions?

Visit our site: https://emergingtrajectories.com/

Please reach out: hello --at-- phaseai --dot-- com
